@@ -1,11 +1,13 @@
+from dataclasses import asdict
 from shutil import rmtree
 
 from dvc.repo import Repo
 from invoke import Collection, task
 from invoke.exceptions import UnexpectedExit
+from structlog import get_logger
 
 from .artifact_context import ArtifactContext
-from .config_loading import DatasetConfig
+from .config_loading import DatasetConfig, RunConfig
 from .helpers import (
     import_env_creator_function,
     import_pipereg,
@@ -24,6 +26,8 @@ from .naming import (
 from .utils import LINE_LEN
 from .validation_functions import validate_dataset, validate_project
 
+logger = get_logger(ctx="invoke task")
+
 
 @task
 def lint(ctx, line_length=LINE_LEN):
@@ -136,7 +140,7 @@ def validate(_, env=None, con="sqlite:///:memory:", draw=False, batch=2000):
 
 
 @task
-def run(_, stage=True):
+def run(_, stage=True, profile=False, force=False):
     conf = {}
     if stage:
         conf["core"] = {"autostage": True}
@@ -145,6 +149,7 @@ def run(_, stage=True):
     pipereg = import_pipereg()
     stage_names = []
     for step in pipereg.steps:
+        logger.info("adding step", step=step)
         step.add_as_stage(dvc_repo)
         stage_names.append(step.name)
 
@@ -153,12 +158,17 @@ def run(_, stage=True):
             continue
         if stage.name in stage_names:
             continue
+
+        logger.info("removing step", step=step)
         dvc_repo.remove(stage.name)
         dvc_repo.lock.lock()
         stage.remove_outs(force=True)
         dvc_repo.lock.unlock()
 
-    dvc_repo.reproduce()
+    conf = RunConfig(profile=profile)
+    logger.info("running repro", **asdict(conf))
+    with conf:
+        dvc_repo.reproduce(force=force)
 
 
 common_tasks = [
