@@ -5,13 +5,15 @@ from yaml import safe_dump
 
 from ...helpers import get_serialized_namespace_dirs
 from ...naming import IMPORTED_NAMESPACES_PATH, ROOT_NS_LOCAL_NAME
-from ...utils import load_named_dict_to_list
+from ...utils import get_dict_factory, load_named_dict_to_list
 from .atoms import NS_ATOM_TYPE
 from .imported_namespace import ImportedNamespace
 from .importer import ImportedMetadata
 from .namespace_metadata import NamespaceMetadata
 from .namespaced_id import NamespacedId
 
+_NS_KEY = "prefix"
+
 
 @dataclass
 class ArtifactMetadata:
@@ -26,7 +28,10 @@ class ArtifactMetadata:
 
     def dump(self):
         serialized_str = safe_dump(
-            {k: asdict(v) for k, v in self.imported_dic.items()},
+            {
+                k: asdict(v, dict_factory=get_dict_factory(_NS_KEY))
+                for k, v in self.imported_dic.items()
+            },
             sort_keys=False,
         )
         IMPORTED_NAMESPACES_PATH.write_text(serialized_str)
@@ -50,7 +55,7 @@ class ArtifactMetadata:
     @classmethod
     def load_serialized(cls) -> "ArtifactMetadata":
         imp_nss = load_named_dict_to_list(
-            IMPORTED_NAMESPACES_PATH, ImportedNamespace, key_name="prefix"
+            IMPORTED_NAMESPACES_PATH, ImportedNamespace, key_name=_NS_KEY
         )
 
         return cls(
